Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: components/sync/engine/cycle/sync_cycle_snapshot.h

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine/cycle/sync_cycle_snapshot.h
diff --git a/components/sync/sessions/sync_session_snapshot.h b/components/sync/engine/cycle/sync_cycle_snapshot.h
similarity index 84%
rename from components/sync/sessions/sync_session_snapshot.h
rename to components/sync/engine/cycle/sync_cycle_snapshot.h
index 2a21d83123e2212f73c2431a0b82c875b769fd1a..f11797728e94f7dce056be7e606ad8865c830cbd 100644
--- a/components/sync/sessions/sync_session_snapshot.h
+++ b/components/sync/engine/cycle/sync_cycle_snapshot.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_SYNC_SESSIONS_SYNC_SESSION_SNAPSHOT_H_
-#define COMPONENTS_SYNC_SESSIONS_SYNC_SESSION_SNAPSHOT_H_
+#ifndef COMPONENTS_SYNC_ENGINE_CYCLE_SYNC_CYCLE_SNAPSHOT_H_
+#define COMPONENTS_SYNC_ENGINE_CYCLE_SYNC_CYCLE_SNAPSHOT_H_
#include <stddef.h>
@@ -13,24 +13,23 @@
#include "base/time/time.h"
#include "components/sync/base/model_type.h"
#include "components/sync/base/progress_marker_map.h"
-#include "components/sync/sessions/model_neutral_state.h"
+#include "components/sync/engine/cycle/model_neutral_state.h"
namespace base {
class DictionaryValue;
}
namespace syncer {
-namespace sessions {
-// An immutable snapshot of state from a SyncSession. Convenient to use as
+// An immutable snapshot of state from a SyncCycle. Convenient to use as
// part of notifications as it is inherently thread-safe.
// TODO(zea): if copying this all over the place starts getting expensive,
// consider passing around immutable references instead of values.
// Default copy and assign welcome.
-class SyncSessionSnapshot {
+class SyncCycleSnapshot {
public:
- SyncSessionSnapshot();
- SyncSessionSnapshot(
+ SyncCycleSnapshot();
+ SyncCycleSnapshot(
const ModelNeutralState& model_neutral_state,
const ProgressMarkerMap& download_progress_markers,
bool is_silenced,
@@ -44,8 +43,8 @@ class SyncSessionSnapshot {
const std::vector<int>& num_entries_by_type,
const std::vector<int>& num_to_delete_entries_by_type,
sync_pb::GetUpdatesCallerInfo::GetUpdatesSource legacy_updates_source);
- SyncSessionSnapshot(const SyncSessionSnapshot& other);
- ~SyncSessionSnapshot();
+ SyncCycleSnapshot(const SyncCycleSnapshot& other);
+ ~SyncCycleSnapshot();
std::unique_ptr<base::DictionaryValue> ToValue() const;
@@ -91,7 +90,6 @@ class SyncSessionSnapshot {
bool is_initialized_;
};
-} // namespace sessions
} // namespace syncer
-#endif // COMPONENTS_SYNC_SESSIONS_SYNC_SESSION_SNAPSHOT_H_
+#endif // COMPONENTS_SYNC_ENGINE_CYCLE_SYNC_CYCLE_SNAPSHOT_H_
« no previous file with comments | « components/sync/engine/cycle/status_counters.cc ('k') | components/sync/engine/cycle/sync_cycle_snapshot.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698